#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .front_faces_transparent import front_faces_transparent as front_faces_transparent_cls
from .projection_1 import projection as projection_cls
from .axes_1 import axes as axes_cls
from .ruler import ruler as ruler_cls
from .title import title as title_cls
from .boundary_marker import boundary_marker as boundary_marker_cls
from .anti_aliasing import anti_aliasing as anti_aliasing_cls
from .reflections import reflections as reflections_cls
from .static_shadows import static_shadows as static_shadows_cls
from .dynamic_shadows import dynamic_shadows as dynamic_shadows_cls
from .grid_plane import grid_plane as grid_plane_cls
from .headlights import headlights as headlights_cls
from .lighting import lighting as lighting_cls
from .view_name import view_name as view_name_cls

class display_states_child(Group):
    fluent_name = ...
    child_names = ...
    front_faces_transparent: front_faces_transparent_cls = ...
    projection: projection_cls = ...
    axes: axes_cls = ...
    ruler: ruler_cls = ...
    title: title_cls = ...
    boundary_marker: boundary_marker_cls = ...
    anti_aliasing: anti_aliasing_cls = ...
    reflections: reflections_cls = ...
    static_shadows: static_shadows_cls = ...
    dynamic_shadows: dynamic_shadows_cls = ...
    grid_plane: grid_plane_cls = ...
    headlights: headlights_cls = ...
    lighting: lighting_cls = ...
    view_name: view_name_cls = ...
    return_type = ...
