#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .background import background as background_cls
from .color_by_type import color_by_type as color_by_type_cls
from .foreground import foreground as foreground_cls
from .by_type import by_type as by_type_cls
from .by_surface import by_surface as by_surface_cls
from .far_field_faces import far_field_faces as far_field_faces_cls
from .inlet_faces import inlet_faces as inlet_faces_cls
from .interior_faces import interior_faces as interior_faces_cls
from .internal_faces import internal_faces as internal_faces_cls
from .outlet_faces import outlet_faces as outlet_faces_cls
from .overset_faces import overset_faces as overset_faces_cls
from .periodic_faces import periodic_faces as periodic_faces_cls
from .rans_les_interface_faces import rans_les_interface_faces as rans_les_interface_faces_cls
from .symmetry_faces import symmetry_faces as symmetry_faces_cls
from .axis_faces import axis_faces as axis_faces_cls
from .free_surface_faces import free_surface_faces as free_surface_faces_cls
from .traction_faces import traction_faces as traction_faces_cls
from .wall_faces import wall_faces as wall_faces_cls
from .interface_faces import interface_faces as interface_faces_cls
from .surface_2 import surface as surface_cls
from .skip_label import skip_label as skip_label_cls
from .automatic_skip import automatic_skip as automatic_skip_cls
from .reset_colors import reset_colors as reset_colors_cls
from .list_colors import list_colors as list_colors_cls

class colors(Group):
    fluent_name = ...
    child_names = ...
    background: background_cls = ...
    color_by_type: color_by_type_cls = ...
    foreground: foreground_cls = ...
    by_type: by_type_cls = ...
    by_surface: by_surface_cls = ...
    far_field_faces: far_field_faces_cls = ...
    inlet_faces: inlet_faces_cls = ...
    interior_faces: interior_faces_cls = ...
    internal_faces: internal_faces_cls = ...
    outlet_faces: outlet_faces_cls = ...
    overset_faces: overset_faces_cls = ...
    periodic_faces: periodic_faces_cls = ...
    rans_les_interface_faces: rans_les_interface_faces_cls = ...
    symmetry_faces: symmetry_faces_cls = ...
    axis_faces: axis_faces_cls = ...
    free_surface_faces: free_surface_faces_cls = ...
    traction_faces: traction_faces_cls = ...
    wall_faces: wall_faces_cls = ...
    interface_faces: interface_faces_cls = ...
    surface: surface_cls = ...
    skip_label: skip_label_cls = ...
    automatic_skip: automatic_skip_cls = ...
    command_names = ...

    def reset_colors(self, ):
        """
        Reset individual mesh surface colors to the defaults.
        """

    def list_colors(self, ):
        """
        List available colors.
        """

    return_type = ...
