#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .body_force_function import body_force_function as body_force_function_cls
from .collision_function import collision_function as collision_function_cls
from .dpm_time_step_function import dpm_time_step_function as dpm_time_step_function_cls
from .erosion_accretion_function import erosion_accretion_function as erosion_accretion_function_cls
from .film_regime_function import film_regime_function as film_regime_function_cls
from .interpolation_function import interpolation_function as interpolation_function_cls
from .impingement_model_function import impingement_model_function as impingement_model_function_cls
from .output_function import output_function as output_function_cls
from .scalar_update_function import scalar_update_function as scalar_update_function_cls
from .source_function import source_function as source_function_cls
from .splashing_distribution_function import splashing_distribution_function as splashing_distribution_function_cls
from .number_of_scalars import number_of_scalars as number_of_scalars_cls
from .maximum_udf_species import maximum_udf_species as maximum_udf_species_cls

class user_defined_functions(Group):
    fluent_name = ...
    child_names = ...
    body_force_function: body_force_function_cls = ...
    collision_function: collision_function_cls = ...
    dpm_time_step_function: dpm_time_step_function_cls = ...
    erosion_accretion_function: erosion_accretion_function_cls = ...
    film_regime_function: film_regime_function_cls = ...
    interpolation_function: interpolation_function_cls = ...
    impingement_model_function: impingement_model_function_cls = ...
    output_function: output_function_cls = ...
    scalar_update_function: scalar_update_function_cls = ...
    source_function: source_function_cls = ...
    splashing_distribution_function: splashing_distribution_function_cls = ...
    number_of_scalars: number_of_scalars_cls = ...
    maximum_udf_species: maximum_udf_species_cls = ...
    return_type = ...
