#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .general import general as general_cls
from .models_1 import models as models_cls
from .materials import materials as materials_cls
from .cell_zone_conditions import cell_zone_conditions as cell_zone_conditions_cls
from .boundary_conditions import boundary_conditions as boundary_conditions_cls
from .reference_values import reference_values as reference_values_cls
from .named_expressions import named_expressions as named_expressions_cls
from .mesh_interfaces import mesh_interfaces as mesh_interfaces_cls
from .geometry_3 import geometry as geometry_cls
from .physics import physics as physics_cls
from .reference_frames import reference_frames as reference_frames_cls

class setup(Group):
    """
    'setup' child.
    """

    fluent_name = "setup"

    child_names = \
        ['general', 'models', 'materials', 'cell_zone_conditions',
         'boundary_conditions', 'reference_values', 'named_expressions',
         'mesh_interfaces', 'geometry', 'physics', 'reference_frames']

    _child_classes = dict(
        general=general_cls,
        models=models_cls,
        materials=materials_cls,
        cell_zone_conditions=cell_zone_conditions_cls,
        boundary_conditions=boundary_conditions_cls,
        reference_values=reference_values_cls,
        named_expressions=named_expressions_cls,
        mesh_interfaces=mesh_interfaces_cls,
        geometry=geometry_cls,
        physics=physics_cls,
        reference_frames=reference_frames_cls,
    )

    return_type = "<object object at 0x7f7d0bfd4d50>"
