#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_14 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .angular import angular as angular_cls
from .p_jump import p_jump as p_jump_cls
from .ai import ai as ai_cls
from .aj import aj as aj_cls
from .ak import ak as ak_cls
from .x_origin import x_origin as x_origin_cls
from .y_origin import y_origin as y_origin_cls
from .z_origin import z_origin as z_origin_cls
from .shift_x import shift_x as shift_x_cls
from .shift_y import shift_y as shift_y_cls
from .shift_z import shift_z as shift_z_cls
from .per_angle import per_angle as per_angle_cls

class periodic_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    angular: angular_cls = ...
    p_jump: p_jump_cls = ...
    ai: ai_cls = ...
    aj: aj_cls = ...
    ak: ak_cls = ...
    x_origin: x_origin_cls = ...
    y_origin: y_origin_cls = ...
    z_origin: z_origin_cls = ...
    shift_x: shift_x_cls = ...
    shift_y: shift_y_cls = ...
    shift_z: shift_z_cls = ...
    per_angle: per_angle_cls = ...
    return_type = ...
